input {
  margin-bottom: $unit;
}
input[type*="text"] {
  background: $blue-dark;
  border: none;
  color: $white;
  display: block;
  outline: none;
  padding: $unit-s;
  width: 100%;
}
label {
  font-family: $header-family;
  font-size: 60%;
  font-weight: bold;
  letter-spacing: 2px;
  text-transform: uppercase;
}
