// Colors
$black: #222222;
$white: #f8f8f8;
$blue: #3498db;
$blue-dark: darken($blue, 27.5%);
// Unit
$unit: 1em;
$unit-s: $unit/2;
$unit-l: $unit*2;
// Body
$background: $blue;
$color: $white;
$font-family: georgia, serif;
$font-size: 120%;
$font-weight: 300;
$line-height: 1.6;
// Type
$title-family: "matchbook", helvetica, sans-serif;
$header-family: "helvetica neue", helvetica, sans-serif;
$header-weight: 100;
