.comment {
  display: table;
  margin-bottom: $unit;
  i {
    display: inline;
  }
  .fa-quote-left {
    padding-right: $unit-s;
  }
  .fa-quote-right {
    padding-left: $unit-s;
  }
  p {
    display: inline;
    margin: 0;
  }
}
