h1,
h2,
h3,
h4,
h5,
h6 {
  font-family: $header-family;
  font-weight: $header-weight;
  letter-spacing: 1px;
  line-height: 1;
}
p {
  color: $blue-dark;
}
.title {
  font-family: $title-family;
  font-size: 4em;
  line-height: 1;
  margin: $unit-s 0 0;
  text-align: center;
}
.username {
  font-family: $title-family;
}
.text-center {
  text-align: center;
}
.font-awesome {
  font-family: FontAwesome;
}
