.btn {
  background: none;
  border: 1px solid $white;
  font-family: $header-family;
  font-size: 60%;
  font-weight: bold;
  letter-spacing: 2px;
  padding: $unit-s $unit;
  text-transform: uppercase;
  &:hover {
    background: $white;
    color: $blue-dark;
  }
}
